import { Ref } from "./JSONSchemaInput";
import { CompressedJSON } from "./CompressedJSON";
import { JSONSchemaStore } from "./JSONSchemaStore";
import { StringInput } from "../support/Support";
import { TypeBuilder } from "../TypeBuilder";
export interface Input {
    readonly kind: string;
    readonly needIR: boolean;
    readonly needSchemaProcessing: boolean;
    finishAddingInputs(): void;
    singleStringSchemaSource(): string | undefined;
    addTypes(typeBuilder: TypeBuilder, inferEnums: boolean, inferDates: boolean, fixedTopLevels: boolean): Promise<void>;
}
export interface JSONSourceData {
    name: string;
    samples: StringInput[];
    description?: string;
}
export declare class JSONInput implements Input {
    private readonly _compressedJSON;
    readonly kind: string;
    readonly needIR: boolean;
    readonly needSchemaProcessing: boolean;
    private _topLevels;
    constructor(_compressedJSON: CompressedJSON);
    private addSample(topLevelName, sample);
    private setDescription(topLevelName, description);
    addSource(source: JSONSourceData): Promise<void>;
    finishAddingInputs(): Promise<void>;
    singleStringSchemaSource(): undefined;
    addTypes(typeBuilder: TypeBuilder, inferEnums: boolean, inferDates: boolean, fixedTopLevels: boolean): Promise<void>;
}
export interface JSONSchemaSourceData {
    name: string;
    uris?: string[];
    schema?: StringInput;
    isConverted?: boolean;
}
export declare class JSONSchemaInput implements Input {
    readonly kind: string;
    readonly needSchemaProcessing: boolean;
    private _schemaStore;
    private _schemaInputs;
    private _schemaSources;
    private _topLevels;
    private _needIR;
    constructor(givenSchemaStore: JSONSchemaStore | undefined);
    readonly needIR: boolean;
    addTopLevel(name: string, ref: Ref): void;
    addTypes(typeBuilder: TypeBuilder): Promise<void>;
    addSource(schemaSource: JSONSchemaSourceData): void;
    finishAddingInputs(): Promise<void>;
    singleStringSchemaSource(): string | undefined;
}
export declare class InputData {
    private _inputs;
    addInput(input: Input): void;
    finishAddingInputs(): Promise<void>;
    addTypes(typeBuilder: TypeBuilder, inferEnums: boolean, inferDates: boolean, fixedTopLevels: boolean): Promise<void>;
    readonly needIR: boolean;
    readonly needSchemaProcessing: boolean;
    singleStringSchemaSource(): string | undefined;
}
